@@ -7,7 +7,7 @@ github3.api
 
 """
 
-from .github import GitHub
+from .github import GitHub, GitHubEnterprise
 
 gh = GitHub()
 
@@ -33,19 +33,23 @@ def authorize(login, password, scopes, note='', note_url='', client_id='',
                         client_secret)
 
 
-def login(username=None, password=None, token=None):
+def login(username=None, password=None, token=None, url=None):
     """Constructs and returns a GitHub session with the username and
-    password, or token
+    password, or token. Will return a GitHubEnterprise session if a url is
+    provided.
 
     :param str username: login name
     :param str password: password for the login
     :param str token: OAuth token
+    :param str url: (optional), URL of a GitHub Enterprise instance
     :returns: :class:`GitHub <github3.github.GitHub>`
     """
     g = None
+
     if (username and password) or token:
-        g = GitHub()
+        g = GitHubEnterprise(url) if url is not None else GitHub()
         g.login(username, password, token)
+
     return g
 
 
@@ -74,74 +78,86 @@ def gitignore_templates():
     return gh.gitignore_templates()
 
 
-def iter_all_repos(number=-1):
+def iter_all_repos(number=-1, etag=None):
     """Iterate over every repository in the order they were created.
 
     :param int number: (optional), number of repositories to return.
         Default: -1, returns all of them
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`Repository <github3.repos.Repository>`
     """
-    return gh.iter_all_repos(number)
+    return gh.iter_all_repos(number, etag)
 
 
-def iter_all_users(number=-1):
+def iter_all_users(number=-1, etag=None):
     """Iterate over every user in the order they signed up for GitHub.
 
     :param int number: (optional), number of users to return. Default: -1,
         returns all of them
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`User <github3.users.User>`
     """
-    return gh.iter_all_users(number)
+    return gh.iter_all_users(number, etag)
 
 
-def iter_events(number=-1):
+def iter_events(number=-1, etag=None):
     """Iterate over public events.
 
     :param int number: (optional), number of events to return. Default: -1
         returns all available events
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`Event <github3.events.Event>`\ s
     """
-    return gh.iter_events(number)
+    return gh.iter_events(number, etag)
 
 
-def iter_followers(username, number=-1):
+def iter_followers(username, number=-1, etag=None):
     """List the followers of ``username``.
 
     :param str username: (required), login of the person to list the followers
         of
     :param int number: (optional), number of followers to return, Default: -1,
         return all of them
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`User <github3.users.User>`
     """
-    return gh.iter_followers(username, number) if username else []
+    return gh.iter_followers(username, number, etag) if username else []
 
 
-def iter_following(username, number=-1):
+def iter_following(username, number=-1, etag=None):
     """List the people ``username`` follows.
 
     :param str username: (required), login of the user
     :param int number: (optional), number of users being followed by username
         to return. Default: -1, return all of them
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`User <github3.users.User>`
     """
-    return gh.iter_following(username, number) if username else []
+    return gh.iter_following(username, number, etag) if username else []
 
 
-def iter_gists(username=None, number=-1):
+def iter_gists(username=None, number=-1, etag=None):
     """Get public gists or gists for the provided username.
 
     :param str username: (optional), if provided, get the gists for this user
         instead of the authenticated user.
     :param int number: (optional), number of gists to return. Default: -1,
         return all of them
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`Gist <github3.gists.Gist>`\ s
     """
-    return gh.iter_gists(username, number)
+    return gh.iter_gists(username, number, etag)
 
 
 def iter_repo_issues(owner, repository, milestone=None, state=None,
                      assignee=None, mentioned=None, labels=None, sort=None,
-                     direction=None, since=None, number=-1):
+                     direction=None, since=None, number=-1, etag=None):
     """List issues on owner/repository. Only owner and repository are
     required.
 
@@ -162,33 +178,42 @@ def iter_repo_issues(owner, repository, milestone=None, state=None,
         2012-05-20T23:10:27Z
     :param int number: (optional), number of issues to return.
         Default: -1 returns all issues
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`Issue <github3.issues.Issue>`\ s
     """
     if owner and repository:
         return gh.iter_repo_issues(owner, repository, milestone, state,
                                    assignee, mentioned, labels, sort,
-                                   direction, since, number)
+                                   direction, since, number, etag)
     return iter([])
 
 
-def iter_orgs(username, number=-1):
+def iter_orgs(username, number=-1, etag=None):
     """List the organizations associated with ``username``.
 
     :param str username: (required), login of the user
     :param int number: (optional), number of orgs to return. Default: -1,
         return all of the issues
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
+    :returns: generator of
+        :class:`Organization <github3.orgs.Organization>`\ s
     """
-    return gh.iter_orgs(username, number) if username else []
+    return gh.iter_orgs(username, number, etag) if username else []
 
 
-def iter_repos(login, type='', sort='', direction='', number=-1):
-    """List public repositories for the specified ``login`` or all
-    repositories for the authenticated user if ``login`` is not
-    provided.
+def iter_user_repos(login, type=None, sort=None, direction=None, number=-1,
+                    etag=None):
+    """List public repositories for the specified ``login``.
+
+    .. versionadded:: 0.6
+
+    .. note:: This replaces github3.iter_repos
 
     :param str login: (required)
     :param str type: (optional), accepted values:
-        ('all', 'owner', 'public', 'private', 'member')
+        ('all', 'owner', 'member')
         API default: 'all'
     :param str sort: (optional), accepted values:
         ('created', 'updated', 'pushed', 'full_name')
@@ -198,35 +223,41 @@ def iter_repos(login, type='', sort='', direction='', number=-1):
         'desc' otherwise
     :param int number: (optional), number of repositories to return.
         Default: -1 returns all repositories
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`Repository <github3.repos.Repository>`
         objects
     """
     if login:
-        return gh.iter_repos(login, type, sort, direction, number)
+        return gh.iter_user_repos(login, type, sort, direction, number, etag)
     return iter([])
 
 
-def iter_starred(username, number=-1):
+def iter_starred(username, number=-1, etag=None):
     """Iterate over repositories starred by ``username``.
 
     :param str username: (optional), name of user whose stars you want to see
     :param int number: (optional), number of repositories to return.
         Default: -1 returns all repositories
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`Repository <github3.repos.Repository>`
     """
-    return gh.iter_starred(username, number)
+    return gh.iter_starred(username, number, etag)
 
 
-def iter_subscriptions(username, number=-1):
+def iter_subscriptions(username, number=-1, etag=None):
     """Iterate over repositories subscribed to by ``username``.
 
     :param str username: (optional), name of user whose subscriptions you want
         to see
     :param int number: (optional), number of repositories to return.
         Default: -1 returns all repositories
+    :param str etag: (optional), ETag from a previous request to the same
+        endpoint
     :returns: generator of :class:`Repository <github3.repos.Repository>`
     """
-    return gh.iter_subscriptions(username, number)
+    return gh.iter_subscriptions(username, number, etag)
 
 
 def create_gist(description, files):
@@ -266,9 +297,13 @@ def markdown(text, mode='', context='', raw=False):
     return gh.markdown(text, mode, context, raw)
 
 
-def octocat():
-    """Returns an easter egg from the API."""
-    return gh.octocat()
+def octocat(say=None):
+    """Returns an easter egg from the API.
+
+    :params str say: (optional), pass in what you'd like Octocat to say
+    :returns: ascii art of Octocat
+    """
+    return gh.octocat(say)
 
 
 def organization(login):
@@ -342,7 +377,7 @@ def user(login):
 
 def ratelimit_remaining():
     """Get the remaining number of requests allowed."""
-    return gh.ratelimit_remaining()
+    return gh.ratelimit_remaining
 
 
 def zen():
