@@ -4,8 +4,8 @@ from github3.repos.commit import RepoCommit
 
 class Branch(GitHubCore):
     """The :class:`Branch <Branch>` object. It holds the information GitHub
-    returns about a branch on a :class:`Repository
-     <github3.repos.repo.Repository>`.
+    returns about a branch on a
+    :class:`Repository <github3.repos.repo.Repository>`.
     """
     def __init__(self, branch, session=None):
         super(Branch, self).__init__(branch, session)
